==> qt5-base-debuginfo-5.4.2-2.tar.xz: usr/src/debug/qt5-base-5.4.2-2/examples/widgets/itemviews/chart/.rcc/qrc_chart.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.4.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.4.2-2.x86_64/src/qtbase-opensource-src-5.4.2/examples/widgets/itemviews/chart/qtdata.cht
  0x0,0x0,0x1,0x90,
  0x53,
  0x63,0x69,0x65,0x6e,0x74,0x69,0x66,0x69,0x63,0x20,0x52,0x65,0x73,0x65,0x61,0x72,
  0x63,0x68,0x2c,0x32,0x31,0x2c,0x23,0x39,0x39,0x65,0x36,0x30,0x30,0xa,0x45,0x6e,
  0x67,0x69,0x6e,0x65,0x65,0x72,0x69,0x6e,0x67,0x20,0x26,0x20,0x44,0x65,0x73,0x69,
  0x67,0x6e,0x2c,0x31,0x38,0x2c,0x23,0x39,0x39,0x63,0x63,0x30,0x30,0xa,0x41,0x75,
  0x74,0x6f,0x6d,0x6f,0x74,0x69,0x76,0x65,0x2c,0x31,0x34,0x2c,0x23,0x39,0x39,0x62,
  0x33,0x30,0x30,0xa,0x41,0x65,0x72,0x6f,0x73,0x70,0x61,0x63,0x65,0x2c,0x31,0x33,
  0x2c,0x23,0x39,0x66,0x39,0x39,0x31,0x61,0xa,0x41,0x75,0x74,0x6f,0x6d,0x61,0x74,
  0x69,0x6f,0x6e,0x20,0x26,0x20,0x4d,0x61,0x63,0x68,0x69,0x6e,0x65,0x20,0x54,0x6f,
  0x6f,0x6c,0x73,0x2c,0x31,0x33,0x2c,0x23,0x61,0x34,0x38,0x30,0x33,0x33,0xa,0x4d,
  0x65,0x64,0x69,0x63,0x61,0x6c,0x20,0x26,0x20,0x42,0x69,0x6f,0x69,0x6e,0x66,0x6f,
  0x72,0x6d,0x61,0x74,0x69,0x63,0x73,0x2c,0x31,0x33,0x2c,0x23,0x61,0x39,0x36,0x36,
  0x34,0x64,0xa,0x49,0x6d,0x61,0x67,0x69,0x6e,0x67,0x20,0x26,0x20,0x53,0x70,0x65,
  0x63,0x69,0x61,0x6c,0x20,0x45,0x66,0x66,0x65,0x63,0x74,0x73,0x2c,0x31,0x32,0x2c,
  0x23,0x61,0x65,0x34,0x64,0x36,0x36,0xa,0x44,0x65,0x66,0x65,0x6e,0x73,0x65,0x2c,
  0x31,0x31,0x2c,0x23,0x62,0x33,0x33,0x33,0x38,0x30,0xa,0x54,0x65,0x73,0x74,0x20,
  0x26,0x20,0x4d,0x65,0x61,0x73,0x75,0x72,0x65,0x6d,0x65,0x6e,0x74,0x20,0x53,0x79,
  0x73,0x74,0x65,0x6d,0x73,0x2c,0x39,0x2c,0x23,0x61,0x36,0x34,0x30,0x38,0x36,0xa,
  0x4f,0x69,0x6c,0x20,0x26,0x20,0x47,0x61,0x73,0x2c,0x39,0x2c,0x23,0x39,0x39,0x34,
  0x64,0x38,0x64,0xa,0x45,0x6e,0x74,0x65,0x72,0x74,0x61,0x69,0x6e,0x6d,0x65,0x6e,
  0x74,0x20,0x26,0x20,0x42,0x72,0x6f,0x61,0x64,0x63,0x61,0x73,0x74,0x69,0x6e,0x67,
  0x2c,0x37,0x2c,0x23,0x38,0x64,0x35,0x61,0x39,0x33,0xa,0x46,0x69,0x6e,0x61,0x6e,
  0x63,0x69,0x61,0x6c,0x2c,0x36,0x2c,0x23,0x38,0x30,0x36,0x36,0x39,0x39,0xa,0x43,
  0x6f,0x6e,0x73,0x75,0x6d,0x65,0x72,0x20,0x45,0x6c,0x65,0x63,0x74,0x72,0x6f,0x6e,
  0x69,0x63,0x73,0x2c,0x34,0x2c,0x23,0x38,0x30,0x37,0x33,0x61,0x36,0xa,0x4f,0x74,
  0x68,0x65,0x72,0x2c,0x33,0x38,0x2c,0x23,0x38,0x30,0x38,0x30,0x62,0x33,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // Charts
  0x0,0x6,
  0x4,0x9e,0x89,0xb3,
  0x0,0x43,
  0x0,0x68,0x0,0x61,0x0,0x72,0x0,0x74,0x0,0x73,
    // qtdata.cht
  0x0,0xa,
  0x8,0xaf,0x5c,0xb4,
  0x0,0x71,
  0x0,0x74,0x0,0x64,0x0,0x61,0x0,0x74,0x0,0x61,0x0,0x2e,0x0,0x63,0x0,0x68,0x0,0x74,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/Charts
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/Charts/qtdata.cht
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_chart)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_chart)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_chart)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_chart)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_chart)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_chart)(); }
   } dummy;
}

==> qt5-base-debuginfo-5.5.1-1.tar.xz: usr/src/debug/qt5-base-5.5.1-1/examples/widgets/itemviews/chart/.rcc/qrc_chart.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.5.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.5.1-1.i686/src/qtbase-opensource-src-5.5.1/examples/widgets/itemviews/chart/qtdata.cht
  0x0,0x0,0x1,0x90,
  0x53,
  0x63,0x69,0x65,0x6e,0x74,0x69,0x66,0x69,0x63,0x20,0x52,0x65,0x73,0x65,0x61,0x72,
  0x63,0x68,0x2c,0x32,0x31,0x2c,0x23,0x39,0x39,0x65,0x36,0x30,0x30,0xa,0x45,0x6e,
  0x67,0x69,0x6e,0x65,0x65,0x72,0x69,0x6e,0x67,0x20,0x26,0x20,0x44,0x65,0x73,0x69,
  0x67,0x6e,0x2c,0x31,0x38,0x2c,0x23,0x39,0x39,0x63,0x63,0x30,0x30,0xa,0x41,0x75,
  0x74,0x6f,0x6d,0x6f,0x74,0x69,0x76,0x65,0x2c,0x31,0x34,0x2c,0x23,0x39,0x39,0x62,
  0x33,0x30,0x30,0xa,0x41,0x65,0x72,0x6f,0x73,0x70,0x61,0x63,0x65,0x2c,0x31,0x33,
  0x2c,0x23,0x39,0x66,0x39,0x39,0x31,0x61,0xa,0x41,0x75,0x74,0x6f,0x6d,0x61,0x74,
  0x69,0x6f,0x6e,0x20,0x26,0x20,0x4d,0x61,0x63,0x68,0x69,0x6e,0x65,0x20,0x54,0x6f,
  0x6f,0x6c,0x73,0x2c,0x31,0x33,0x2c,0x23,0x61,0x34,0x38,0x30,0x33,0x33,0xa,0x4d,
  0x65,0x64,0x69,0x63,0x61,0x6c,0x20,0x26,0x20,0x42,0x69,0x6f,0x69,0x6e,0x66,0x6f,
  0x72,0x6d,0x61,0x74,0x69,0x63,0x73,0x2c,0x31,0x33,0x2c,0x23,0x61,0x39,0x36,0x36,
  0x34,0x64,0xa,0x49,0x6d,0x61,0x67,0x69,0x6e,0x67,0x20,0x26,0x20,0x53,0x70,0x65,
  0x63,0x69,0x61,0x6c,0x20,0x45,0x66,0x66,0x65,0x63,0x74,0x73,0x2c,0x31,0x32,0x2c,
  0x23,0x61,0x65,0x34,0x64,0x36,0x36,0xa,0x44,0x65,0x66,0x65,0x6e,0x73,0x65,0x2c,
  0x31,0x31,0x2c,0x23,0x62,0x33,0x33,0x33,0x38,0x30,0xa,0x54,0x65,0x73,0x74,0x20,
  0x26,0x20,0x4d,0x65,0x61,0x73,0x75,0x72,0x65,0x6d,0x65,0x6e,0x74,0x20,0x53,0x79,
  0x73,0x74,0x65,0x6d,0x73,0x2c,0x39,0x2c,0x23,0x61,0x36,0x34,0x30,0x38,0x36,0xa,
  0x4f,0x69,0x6c,0x20,0x26,0x20,0x47,0x61,0x73,0x2c,0x39,0x2c,0x23,0x39,0x39,0x34,
  0x64,0x38,0x64,0xa,0x45,0x6e,0x74,0x65,0x72,0x74,0x61,0x69,0x6e,0x6d,0x65,0x6e,
  0x74,0x20,0x26,0x20,0x42,0x72,0x6f,0x61,0x64,0x63,0x61,0x73,0x74,0x69,0x6e,0x67,
  0x2c,0x37,0x2c,0x23,0x38,0x64,0x35,0x61,0x39,0x33,0xa,0x46,0x69,0x6e,0x61,0x6e,
  0x63,0x69,0x61,0x6c,0x2c,0x36,0x2c,0x23,0x38,0x30,0x36,0x36,0x39,0x39,0xa,0x43,
  0x6f,0x6e,0x73,0x75,0x6d,0x65,0x72,0x20,0x45,0x6c,0x65,0x63,0x74,0x72,0x6f,0x6e,
  0x69,0x63,0x73,0x2c,0x34,0x2c,0x23,0x38,0x30,0x37,0x33,0x61,0x36,0xa,0x4f,0x74,
  0x68,0x65,0x72,0x2c,0x33,0x38,0x2c,0x23,0x38,0x30,0x38,0x30,0x62,0x33,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // Charts
  0x0,0x6,
  0x4,0x9e,0x89,0xb3,
  0x0,0x43,
  0x0,0x68,0x0,0x61,0x0,0x72,0x0,0x74,0x0,0x73,
    // qtdata.cht
  0x0,0xa,
  0x8,0xaf,0x5c,0xb4,
  0x0,0x71,
  0x0,0x74,0x0,0x64,0x0,0x61,0x0,0x74,0x0,0x61,0x0,0x2e,0x0,0x63,0x0,0x68,0x0,0x74,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/Charts
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/Charts/qtdata.cht
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_chart)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_chart)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_chart)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_chart)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_chart)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_chart)(); }
   } dummy;
}
